@@ -340,7 +340,7 @@ class FileSystemDocsLoader(BaseDocsLoader):
             current_dir = app_dir
         for name in os.listdir(current_dir):
             current_path = os.path.join(current_dir, name)
-            rel_path = current_path.split("%s/" % app_dir)[1]
+            rel_path = os.path.relpath(current_path, app_dir)
             if name.startswith('.'):
                 continue
             elif name.startswith('_'):
@@ -437,10 +437,10 @@ class FileSystemDocsLoader(BaseDocsLoader):
                     if filename.startswith('.'):
                         continue
                     else:
-                        file_path = os.path.join(root, filename) 
-                        name = file_path.split('%s/' % attach_dir)[1]
+                        file_path = os.path.join(root, filename)
+                        name = os.path.relpath(file_path, attach_dir)
                         if vendor is not None:
-                            name = os.path.join('vendor/%s' % vendor, name)
+                            name = os.path.join('vendor', vendor, name)
                         _signatures[name] = sign_file(file_path)
                         _attachments[name] = file_path
                         _length[name] = int(os.path.getsize(file_path))
